"""Zope ODBC Database Connection"""

__copyright__ = "Copyright 2004, Timothy R. Morgan."
__license__ = "Released under the terms of the Zope Public License (ZPL) Version 2.1 (see license.txt)"

import string

import Shared.DC.ZRDB.THUNK
#TM = Shared.DC.ZRDB.THUNK.THUNKED_TM
TM = Shared.DC.ZRDB.TM.TM

from odbc import odbc

from DateTime import DateTime

type_mapping = {
    'STRING' : 's',
    'NUMBER' : 'i',
    'DATE'   : 'd',
    'FLOAT'  : 'n',
}

class DB(TM) :

    def __init__(self, connection_string):
        if connection_string.find('/') == -1:
            connection_string = connection_string.replace(' ', '/')
        self.db = odbc(connection_string)

    def _begin(self):
        pass

    def _finish(self):
        self.db.commit()

    def _abort(self):
        self.db.rollback()

    def query(self, query_string, max_rows=100000):
        self._register()

        description = []
        result = []
        queries = [q.strip() for q in query_string.split('\0')]
        cursor = self.db.cursor()
        for query in queries:
            cursor.execute(query)
            if cursor.description:
                description = cursor.description
                result = cursor.fetchmany(max_rows)
                break
        cursor.close()

        result = [list(row) for row in list(result)]

        items = []
        index = 0
        for d in description :
            col_type = type_mapping[d[1]]
            if col_type == 'd':
                for row in result:
                    if row[index] != None:
                        try:
                            row[index] = DateTime(str(row[index]))
                        except:
                            pass
            items.append(
                {"name": d[0],
                 "type": col_type,
                 "width": d[4],
                 "null": d[6],
                }
            )
            index += 1

        return (items, result)